prod

Function prod 

pub fn prod(arr: &mut Array) -> Result<Dynamic, Box<EvalAltResult>>
Compute the product of an array. Fails if the input is not an array, or if it is an array with elements other than INT or FLOAT.

let data = [1, 2, 3];
let m = prod(data);
assert_eq(m, 6);
let data = [3, 6, 10];
let m = prod(data);
assert_eq(m, 180);