pub fn array_max(arr: &mut Array) -> Result<Dynamic, Box<EvalAltResult>>Expand description
Return the highest value from an array. Fails if the input is not an array, or if it is an array with elements other than INT or FLOAT.
let the_highest_number = max([2, 3, 4, 5]);
assert_eq(the_highest_number, 5);let the_highest_number = max([2, 3.0, 4.12, 5]);
assert_eq(the_highest_number, 5.0);