pub fn array_min(arr: &mut Array) -> Result<Dynamic, Box<EvalAltResult>>Expand description
Return the lowest value from an array. Fails if the input is not an array, or if it is an array with elements other than INT or FLOAT.
let the_lowest_number = min([2, 3, 4, 5]);
assert_eq(the_lowest_number, 2);let the_lowest_number = min([2, 3.0, 4.12, 5]);
assert_eq(the_lowest_number, 2.0);