pub fn mean(arr: &mut Array) -> Result<Dynamic, Box<EvalAltResult>>Expand description
Return the average of an array. Fails if the input is not an array, or if it is an array with elements other than INT or FLOAT.
let data = [1, 2, 3];
let m = mean(data);
assert_eq(m, 2.0);